@@ -5,8 +5,8 @@
 #' station you want, you can quickly get all manner of data from it
 #'
 #' @export
-#' @import rgeos rgdal sp
-#' 
+#' @importFrom rgdal ogrListLayers readOGR
+#'
 #' @template rnoaa
 #' @template rnoaa2
 #' @template stations
@@ -44,8 +44,6 @@
 #' ncdc_stations(datasetid='PRECIP_HLY', startdate='19900101', enddate='19901231')
 #'
 #' # Search for stations by spatial extent
-#' ## Search using a single point, given by a lat long pair
-#' ncdc_stations(extent=c(33.95,-118.40))
 #' ## Search using a bounding box, w/ lat/long of the SW corner, then of NE corner
 #' ncdc_stations(extent=c(47.5204,-122.2047,47.6139,-122.1065))
 #' }
@@ -53,43 +51,40 @@
 ncdc_stations <- function(stationid=NULL, datasetid=NULL, datatypeid=NULL, locationid=NULL,
   startdate=NULL, enddate=NULL, sortfield=NULL, sortorder=NULL, limit=25, offset=NULL,
   datacategoryid=NULL, extent=NULL, radius=10, token=NULL, dataset=NULL,
-  station=NULL, location=NULL, locationtype=NULL, page=NULL, ...)
-{
+  station=NULL, location=NULL, locationtype=NULL, page=NULL, ...) {
+
   token <- check_key(token)
 
-  if(!is.null(stationid)){
+  if (!is.null(stationid)) {
     url <- sprintf('http://www.ncdc.noaa.gov/cdo-web/api/v2/stations/%s', stationid)
     args <- list()
-  } else
-  {
+  } else {
     url <- 'http://www.ncdc.noaa.gov/cdo-web/api/v2/stations'
-    if(!is.null(extent)){
-      if(length(extent) == 4){ extent <- paste0(extent, collapse = ",") } else
-      {
-        extent <- latlong2bbox(lat=extent[1], lon=extent[2], radius=radius)
-      }
+    if (!is.null(extent)) {
+      stopifnot(length(extent) == 4)
+      stopifnot(is(extent, "numeric"))
+      extent <- paste0(extent, collapse = ",")
     }
-    args <- compact(list(datasetid=datasetid, datatypeid=datatypeid,
-                         locationid=locationid, startdate=startdate,
-                         enddate=enddate, sortfield=sortfield, sortorder=sortorder,
-                         limit=limit, offset=offset, datacategoryid=datacategoryid,
-                         extent=extent))
+    args <- noaa_compact(list(datasetid = datasetid, datatypeid = datatypeid,
+                         locationid = locationid, startdate = startdate,
+                         enddate = enddate, sortfield = sortfield, sortorder = sortorder,
+                         limit = limit, offset = offset, datacategoryid = datacategoryid,
+                         extent = extent))
   }
 
-  temp <- GET(url, query=args, add_headers("token" = token), ...)
+  temp <- GET(url, query = args, add_headers("token" = token), ...)
   tt <- check_response(temp)
-  if(is(temp, "character")){
-    all <- list(meta=NULL, data=NULL)
+  if (is(temp, "character")) {
+    all <- list(meta = NULL, data = NULL)
   } else {
-    if(!is.null(stationid)){
-      dat <- data.frame(tt, stringsAsFactors=FALSE)
-      all <- list(meta=NULL, data=dat)
-    } else
-    {
-      dat <- do.call(rbind.fill, lapply(tt$results, function(x) data.frame(x, stringsAsFactors=FALSE)))
+    if (!is.null(stationid)) {
+      dat <- data.frame(tt, stringsAsFactors = FALSE)
+      all <- list(meta = NULL, data = dat)
+    } else {
+      dat <- do.call(rbind.fill, lapply(tt$results, function(x) data.frame(x, stringsAsFactors = FALSE)))
       meta <- tt$metadata$resultset
-      atts <- list(totalCount=meta$count, pageCount=meta$limit, offset=meta$offset)
-      all <- list(meta=atts, data=dat)
+      atts <- list(totalCount = meta$count, pageCount = meta$limit, offset = meta$offset)
+      all <- list(meta = atts, data = dat)
     }
   }
   class(all) <- "ncdc_stations"
