@@ -1,10 +1,12 @@
 #' Get sea ice data.
 #'
-#' @import rgdal ggplot2
+#' @import ggplot2
 #' @param url A url for a NOAA sea ice ftp file
 #' @param ... Further arguments passed on to readshpfile function, see
 #'    \code{readshpfile}
 #' @return A data.frame
+#' @details If you want to reproject the shape files, use
+#' \code{\link{readshpfile}} to read in shape file, then reproject, and so on.
 #' @export
 #' @examples \dontrun{
 #' # Look at data.frame's for a series of years for Feb, South pole
@@ -33,14 +35,14 @@
 #'   theme_ice() +
 #'   facet_wrap(~ .id)
 #' }
-seaice <- function(url, ...)
-{
+seaice <- function(url, ...) {
   tt <- readshpfile(url, ...)
   fortify(tt)
 }
 
 #' Make all urls for sea ice data
-#' @import lubridate stringr
+#'
+#' @importFrom lubridate year today month
 #' @param yr Year (numeric)
 #' @param mo Month, as character abbrevation of a month  (character)
 #' @param Pole One of S (south) or N (north) (character)
@@ -60,78 +62,81 @@ seaice <- function(url, ...)
 #' }
 #' @export
 #' @keywords internal
-seaiceeurls <- function(yr=NULL, mo=NULL, pole=NULL)
-{
-  eachmonth <- sprintf('ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/shapefiles/%s/shp_extent/', month.abb)
-  yrs_prev <- seq(1979, year(today())-1, 1)
-  months_prevyr <- c(paste0(0, seq(1,9)), c(10,11,12))
-  yrs_months <- do.call(c, lapply(yrs_prev, function(x) paste(x, months_prevyr, sep='')))
-  urls <- do.call(c, lapply(c('S','N'), function(x) paste(eachmonth, 'extent_', x, '_', yrs_months, '_polygon.zip', sep='')))
+seaiceeurls <- function(yr=NULL, mo=NULL, pole=NULL) {
+  eachmonth <- sprintf(seaiceftp(), month.abb)
+  yrs_prev <- seq(1979, year(today()) - 1, 1)
+  months_prevyr <- c(paste0(0, seq(1, 9)), c(10, 11, 12))
+  yrs_months <- do.call(c, lapply(yrs_prev, function(x) paste(x, months_prevyr, sep = '')))
+  urls <- do.call(c, lapply(c('S', 'N'), function(x) {
+    paste(eachmonth, 'extent_', x, '_', yrs_months, '_polygon.zip', sep = '')
+  }))
 
   months_thisyr <- paste0(0, seq(1,month(today())))
   yrs_months_thisyr <- paste0(2013, months_thisyr)
-  eachmonth_thiyr <- eachmonth[1:grep(month(today() - months(1), label=TRUE, abbr=TRUE), eachmonth)]
-  urls_thisyr <- do.call(c, lapply(c('S','N'), function(x) paste(eachmonth_thiyr, 'extent_', x, '_', yrs_months_thisyr, '_polygon.zip', sep='')))
+  eachmonth_thiyr <- eachmonth[1:grep(month(today() - months(1), label = TRUE, abbr = TRUE), eachmonth)]
+  urls_thisyr <- do.call(c, lapply(c('S', 'N'), function(x) {
+    paste(eachmonth_thiyr, 'extent_', x, '_', yrs_months_thisyr, '_polygon.zip', sep = '')
+  }))
 
   allurls <- c(urls, urls_thisyr)
 
-  if(!is.null(pole)) pole <- sprintf("_%s_", pole)
-  if(!is.null(yr)) yr <- sprintf("_%s", yr)
+  if (!is.null(pole)) pole <- sprintf("_%s_", pole)
+  if (!is.null(yr)) yr <- sprintf("_%s", yr)
 
-  if(!is.null(yr) & is.null(mo) & is.null(pole))
-    ss <- grep(yr, allurls, value=TRUE)
-  if(is.null(yr) & !is.null(mo) & is.null(pole))
-    ss <- grep(mo, allurls, value=TRUE)
-  if(is.null(yr) & is.null(mo) & !is.null(pole))
-    ss <- grep(pole, allurls, value=TRUE)
-  if(!is.null(yr) & !is.null(mo) & is.null(pole))
-    ss <- grep(yr, grep(mo, allurls, value=TRUE), value=TRUE)
-  if(!is.null(yr) & is.null(mo) & !is.null(pole))
-    ss <- grep(yr, grep(pole, allurls, value=TRUE), value=TRUE)
-  if(is.null(yr) & !is.null(mo) & !is.null(pole))
-    ss <- grep(pole, grep(mo, allurls, value=TRUE), value=TRUE)
-  if(!is.null(yr) & !is.null(mo) & !is.null(pole))
-    ss <- grep(yr, grep(pole, grep(mo, allurls, value=TRUE), value=TRUE), value=TRUE)
+  if (!is.null(yr) & is.null(mo) & is.null(pole))
+    ss <- grep(yr, allurls, value = TRUE)
+  if (is.null(yr) & !is.null(mo) & is.null(pole))
+    ss <- grep(mo, allurls, value = TRUE)
+  if (is.null(yr) & is.null(mo) & !is.null(pole))
+    ss <- grep(pole, allurls, value = TRUE)
+  if (!is.null(yr) & !is.null(mo) & is.null(pole))
+    ss <- grep(yr, grep(mo, allurls, value = TRUE), value = TRUE)
+  if (!is.null(yr) & is.null(mo) & !is.null(pole))
+    ss <- grep(yr, grep(pole, allurls, value = TRUE), value = TRUE)
+  if (is.null(yr) & !is.null(mo) & !is.null(pole))
+    ss <- grep(pole, grep(mo, allurls, value = TRUE), value = TRUE)
+  if (!is.null(yr) & !is.null(mo) & !is.null(pole))
+    ss <- grep(yr, grep(pole, grep(mo, allurls, value = TRUE), value = TRUE), value = TRUE)
 
   return( ss )
 }
 
+seaiceftp <- function() 'ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/shapefiles/%s/shp_extent/'
+
 #' Function to read shapefiles
-#' @import maptools
 #' @param x A url
 #' @param storepath Path to store data in
 #' @return An object of class sp
 #' @export
 #' @keywords internal
-readshpfile <- function(x, storepath=NULL)
-{
-  filename <- str_split(x, '/')[[1]][length(str_split(x, '/')[[1]])]
-  filename_noending <- str_split(filename, "\\.")[[1]][[1]]
-  if(is.null(storepath)){ storepath <- tempdir() }
+readshpfile <- function(x, storepath = NULL) {
+  filename <- strsplit(x, '/')[[1]][length(strsplit(x, '/')[[1]])]
+  filename_noending <- strsplit(filename, "\\.")[[1]][[1]]
+  if (is.null(storepath)) {
+    storepath <- tempdir()
+  }
   path_write <- paste0(storepath, '/', filename_noending)
   path <- paste0(storepath, '/', filename)
-#   path_shp <- str_replace(path, ".zip", ".shp")
-  bb <- try(download.file(x, path), silent=TRUE)
-  if(class(bb) == "try-error")
+  bb <- try(download.file(x, path), silent = TRUE)
+  if (class(bb) == "try-error") {
     stop('Data not available, ftp server may be down')
-  dir.create(path_write, showWarnings=FALSE)
-  unzip(path, exdir=path_write)
+  }
+  dir.create(path_write, showWarnings = FALSE)
+  unzip(path, exdir = path_write)
   my_layer <- ogrListLayers(path.expand(path_write))
-  readOGR(path.expand(path_write), layer=my_layer)
-#   spTransform(temp, CRS("+proj=longlat"))
-#   temp <- readShapePoly(path_shp, proj4string=CRS("+proj=utm +datum=WGS84"))
+  readOGR(path.expand(path_write), layer = my_layer)
 }
 
 #' ggplot2 map theme
 #' @import ggplot2
 #' @export
 #' @keywords internal
-theme_ice <- function(){
-  list(theme_bw(base_size=18),
+theme_ice <- function() {
+  list(theme_bw(base_size = 18),
        theme(panel.border = element_blank(),
              panel.grid.major = element_blank(),
              panel.grid.minor = element_blank(),
              axis.text = element_blank(),
              axis.ticks = element_blank()),
-       labs(x='',y=''))
+       labs(x = '', y = ''))
 }
