@@ -1,15 +1,17 @@
 context("ncdc_locs_cats")
 
-key='YZJVDgzurxvMqiIcfpzrOozpRBVvTBhE'
-
-Sys.sleep(time = 0.5)
-tt <- ncdc_locs_cats(token=key)
-Sys.sleep(time = 0.5)
-uu <- ncdc_locs_cats(locationcategoryid='CLIM_REG', token=key)
-Sys.sleep(time = 0.5)
-vv <- ncdc_locs_cats(startdate='1970-01-01', token=key)
-
-test_that("ncdc_locs_cats returns the correct class", {
+test_that("ncdc_locs_cats returns the correct ...", {
+  skip_on_cran()
+  
+  Sys.sleep(time = 0.5)
+  tt <- ncdc_locs_cats()
+  Sys.sleep(time = 0.5)
+  uu <- ncdc_locs_cats(locationcategoryid='CLIM_REG')
+  Sys.sleep(time = 0.5)
+  vv <- ncdc_locs_cats(startdate='1970-01-01')
+  
+  
+  # class
   expect_is(tt, "ncdc_locs_cats")
   expect_is(uu$data, "data.frame")
   expect_is(vv, "ncdc_locs_cats")
@@ -17,9 +19,8 @@ test_that("ncdc_locs_cats returns the correct class", {
   expect_is(tt$data, "data.frame")
   expect_is(tt$meta$totalCount, "integer")
   expect_is(tt$data$id, "character")
-})
 
-test_that("ncdc_locs_cats returns the correct dimensions", {
+  # dimensions
   expect_equal(length(tt$meta), 3)
   expect_equal(NCOL(tt$data), 2)
   expect_equal(dim(uu$data), c(1,2))
